==========
ceph-medic
==========

``ceph-medic`` is a tool that performs checks against Ceph clusters to identify common issues preventing proper functionality. It supports Kubernetes and OpenShift, using ``kubectl`` and ``oc``, respectively. It requires non-interactive SSH access to accounts that can ``sudo`` without a password prompt.

Full usage documentation can be found at: http://docs.ceph.com/ceph-medic
